************
Neuron types
************

These neuron types can be used in any place that
`Nengo neuron types
<https://www.nengo.ai/nengo/frontend_api.html#neuron-types>`_
can be used.

.. default-role:: obj

.. autoclass:: nengo_extras.neurons.SoftLIFRate

.. autoclass:: nengo_extras.neurons.FastLIF

Utilities
=========

.. autofunction:: nengo_extras.neurons.spikes2events

.. autofunction:: nengo_extras.neurons.rates_isi

.. autofunction:: nengo_extras.neurons.rates_kernel
